Documentation
¶
Index ¶
Constants ¶
const FormEncodedHeader = "application/x-www-form-urlencoded; charset=utf-8"
const JsonByteStreamHeader = "application/json; charset=utf-8"
Variables ¶
This section is empty.
Functions ¶
func HandleKnockout ¶
Function to knockout due to an error, sending back the isLogged object (can just be log or full object in itself)
Types ¶
type Log ¶
Log is the high level collection of whats happened Intended to be passed to functions to add failures as nessasary Does not contain debug information for the log etc, as this is handled on fatality Failures on addition can knockout the log causing a fatality FatalityHandler is what handles when this happens, terminating the request and sending log to the service
func (*Log) AddFailure ¶
func (*Log) AddNewFailureFromError ¶
Click to show internal directories.
Click to hide internal directories.